@@ -3,7 +3,7 @@ from django.contrib.auth.models import User
 from hitcount.models import HitCountMixin, HitCount
 from taggit.managers import TaggableManager
 from django.contrib.contenttypes.fields import GenericRelation
-from _data.blog import CATEGORY
+from _data.zenblog_contents import CATEGORY
 
 STATUS = (
     (0, "Draft"),
