@@ -1,7 +1,7 @@
 from django import template
 from ..models import Post, CATEGORY
 from ..forms import Search
-from _data.blog import context
+from _data.zenblog_contents import context
 import re
 
 register = template.Library()
